@@ -15,23 +15,16 @@
 #include "useridlistmodel.h"
 
 #include "keycache.h"
-#include "utils/formatting.h"
+
+#include <libkleo/formatting.h>
 
 #include <KLocalizedString>
 
-#include <QVariant>
 #include <QIcon>
+#include <QVariant>
 
 #include <gpgme++/key.h>
 
-#include <gpgme++/gpgmepp_version.h>
-#if GPGMEPP_VERSION >= 0x10E00 // 1.14.0
-# define GPGME_HAS_REMARKS
-#endif
-#if GPGMEPP_VERSION >= 0x10E01 // 1.14.1
-# define GPGME_USERID_SIGNATURES_ARE_SORTABLE
-#endif
-
 using namespace GpgME;
 using namespace Kleo;
 
@@ -46,17 +39,17 @@ public:
         : mParentItem{parentItem}
         , mSig{sig}
     {
-        mItemData  << QString::fromUtf8(sig.signerKeyID())
-                   << Formatting::prettyName(sig)
-                   << Formatting::prettyEMail(sig)
-                   << Formatting::creationDateString(sig)
-                   << Formatting::expirationDateString(sig)
-                   << Formatting::validityShort(sig)
-                   << (sig.isExportable() ? QStringLiteral("✓") : QString());
+        mItemData << QString::fromUtf8(sig.signerKeyID()) //
+                  << Formatting::prettyName(sig) //
+                  << Formatting::prettyEMail(sig) //
+                  << Formatting::creationDateString(sig) //
+                  << Formatting::expirationDateString(sig) //
+                  << Formatting::validityShort(sig) //
+                  << (sig.isExportable() ? QStringLiteral("✓") : QString());
 
         QString lastNotation;
         if (showRemarks && parentItem) {
-            for (const auto &notation: sig.notations()) {
+            for (const auto &notation : sig.notations()) {
                 if (notation.name() && !strcmp(notation.name(), "rem@gnupg.org")) {
                     lastNotation = QString::fromUtf8(notation.value());
                 }
@@ -79,13 +72,13 @@ public:
     // The root item
     UIDModelItem()
     {
-        mItemData << i18n("ID")
-                  << i18n("Name")
-                  << i18n("E-Mail")
-                  << i18n("Valid From")
-                  << i18n("Valid Until")
-                  << i18n("Status")
-                  << i18n("Exportable")
+        mItemData << i18n("ID") //
+                  << i18n("Name") //
+                  << i18n("E-Mail") //
+                  << i18n("Valid From") //
+                  << i18n("Valid Until") //
+                  << i18n("Status") //
+                  << i18n("Exportable") //
                   << i18n("Tags");
 #ifdef GPGMEPP_SUPPORTS_TRUST_SIGNATURES
         mItemData << i18n("Trust Signature For");
@@ -156,7 +149,7 @@ public:
     int row() const
     {
         if (mParentItem) {
-            return mParentItem->mChildItems.indexOf(const_cast<UIDModelItem*>(this));
+            return mParentItem->mChildItems.indexOf(const_cast<UIDModelItem *>(this));
         }
         return 0;
     }
@@ -177,7 +170,7 @@ public:
     }
 
 private:
-    QList<UIDModelItem*> mChildItems;
+    QList<UIDModelItem *> mChildItems;
     QList<QVariant> mItemData;
     UIDModelItem *mParentItem = nullptr;
     UserID::Signature mSig;
@@ -207,9 +200,7 @@ void UserIDListModel::setKey(const Key &key)
         auto uidItem = new UIDModelItem(uid, mRootItem.get());
         mRootItem->appendChild(uidItem);
         std::vector<UserID::Signature> sigs = uid.signatures();
-#ifdef GPGME_USERID_SIGNATURES_ARE_SORTABLE
         std::sort(sigs.begin(), sigs.end());
-#endif
         for (const auto &sig : sigs) {
             auto sigItem = new UIDModelItem(sig, uidItem, mRemarksEnabled);
             uidItem->appendChild(sigItem);
@@ -222,7 +213,7 @@ void UserIDListModel::setKey(const Key &key)
 int UserIDListModel::columnCount(const QModelIndex &parent) const
 {
     if (parent.isValid()) {
-        return static_cast<UIDModelItem*>(parent.internalPointer())->columnCount();
+        return static_cast<UIDModelItem *>(parent.internalPointer())->columnCount();
     }
 
     if (!mRootItem) {
@@ -238,7 +229,7 @@ int UserIDListModel::rowCount(const QModelIndex &parent) const
         return 0;
     }
 
-    const UIDModelItem *const parentItem = !parent.isValid() ? mRootItem.get() : static_cast<UIDModelItem*>(parent.internalPointer());
+    const UIDModelItem *const parentItem = !parent.isValid() ? mRootItem.get() : static_cast<UIDModelItem *>(parent.internalPointer());
     return parentItem->childCount();
 }
 
@@ -248,7 +239,7 @@ QModelIndex UserIDListModel::index(int row, int column, const QModelIndex &paren
         return {};
     }
 
-    const UIDModelItem *const parentItem = !parent.isValid() ? mRootItem.get() : static_cast<UIDModelItem*>(parent.internalPointer());
+    const UIDModelItem *const parentItem = !parent.isValid() ? mRootItem.get() : static_cast<UIDModelItem *>(parent.internalPointer());
     UIDModelItem *const childItem = parentItem->child(row);
     if (childItem) {
         return createIndex(row, column, childItem);
@@ -262,7 +253,7 @@ QModelIndex UserIDListModel::parent(const QModelIndex &index) const
     if (!index.isValid()) {
         return {};
     }
-    auto childItem = static_cast<UIDModelItem*>(index.internalPointer());
+    auto childItem = static_cast<UIDModelItem *>(index.internalPointer());
     UIDModelItem *parentItem = childItem->parentItem();
 
     if (parentItem == mRootItem.get()) {
@@ -288,12 +279,11 @@ QVariant UserIDListModel::data(const QModelIndex &index, int role) const
         return QVariant();
     }
 
-    if (role != Qt::DisplayRole && role != Qt::EditRole && role != Qt::ToolTipRole &&
-        role != Qt::DecorationRole) {
+    if (role != Qt::DisplayRole && role != Qt::EditRole && role != Qt::ToolTipRole && role != Qt::DecorationRole) {
         return QVariant();
     }
 
-    auto item = static_cast<UIDModelItem*>(index.internalPointer());
+    auto item = static_cast<UIDModelItem *>(index.internalPointer());
 
     if (role == Qt::ToolTipRole) {
         return item->toolTip(index.column());
@@ -306,12 +296,12 @@ QVariant UserIDListModel::data(const QModelIndex &index, int role) const
     return item->data(index.column());
 }
 
-UserID UserIDListModel::userID(const QModelIndex& index) const
+UserID UserIDListModel::userID(const QModelIndex &index) const
 {
     if (!index.isValid()) {
         return UserID();
     }
-    UIDModelItem *item = static_cast<UIDModelItem*>(index.internalPointer());
+    UIDModelItem *item = static_cast<UIDModelItem *>(index.internalPointer());
     return item->uid();
 }
 
@@ -322,7 +312,7 @@ QVector<UserID> UserIDListModel::userIDs(const QModelIndexList &indexes) const
         if (!idx.isValid()) {
             continue;
         }
-        auto item = static_cast<UIDModelItem*>(idx.internalPointer());
+        auto item = static_cast<UIDModelItem *>(idx.internalPointer());
         if (!item->uid().isNull()) {
             ret << item->uid();
         }
@@ -330,12 +320,12 @@ QVector<UserID> UserIDListModel::userIDs(const QModelIndexList &indexes) const
     return ret;
 }
 
-UserID::Signature UserIDListModel::signature(const QModelIndex& index) const
+UserID::Signature UserIDListModel::signature(const QModelIndex &index) const
 {
     if (!index.isValid()) {
         return UserID::Signature();
     }
-    UIDModelItem *item = static_cast<UIDModelItem*>(index.internalPointer());
+    UIDModelItem *item = static_cast<UIDModelItem *>(index.internalPointer());
     return item->signature();
 }
 
@@ -346,7 +336,7 @@ QVector<UserID::Signature> UserIDListModel::signatures(const QModelIndexList &in
         if (!idx.isValid()) {
             continue;
         }
-        auto item = static_cast<UIDModelItem*>(idx.internalPointer());
+        auto item = static_cast<UIDModelItem *>(idx.internalPointer());
         if (!item->signature().isNull()) {
             ret << item->signature();
         }
